package com.sf.order.service;


import com.sf.order.domain.OrderInfo;
import com.sf.order.domain.dto.OrderCreateDto;
import com.sf.order.domain.req.OrderListReqVo;
import com.sf.order.domain.res.OrderListResVo;

import java.util.List;

/**
 * 订单基础信息Service接口
 *
 * @author ztzh
 * @date 2024-04-09
 */
public interface IOrderInfoService
{
    /**
     * 查询订单基础信息
     *
     * @param id 订单基础信息主键
     * @return 订单基础信息
     */
    public OrderInfo selectOrderInfoById(Long id);

    /**
     * 查询订单基础信息列表
     *
     * @param orderInfo 订单基础信息
     * @return 订单基础信息集合
     */
    public List<OrderInfo> selectOrderInfoList(OrderInfo orderInfo);

    /**
     * 查询订单基础信息列表
     */
    List<OrderListResVo> queryList(OrderListReqVo vo);

    /**
     * 新增订单基础信息
     *
     * @param orderInfo 订单基础信息
     * @return 结果
     */
    public Long createOrder(OrderCreateDto orderInfo);

    /**
     * 修改订单基础信息
     *
     * @param orderInfo 订单基础信息
     * @return 结果
     */
    public int updateOrderInfo(OrderInfo orderInfo);

    /**
     * 批量删除订单基础信息
     *
     * @param ids 需要删除的订单基础信息主键集合
     * @return 结果
     */
    public int deleteOrderInfoByIds(Long[] ids);

    /**
     * 删除订单基础信息信息
     *
     * @param id 订单基础信息主键
     * @return 结果
     */
    public int deleteOrderInfoById(Long id);

    void orderPay(Long orderId);

    OrderInfo selectOrderInfoByOrderNo(String orderNo);

    void insertOrder(OrderInfo orderInfo);

}
